@@ -427,6 +427,13 @@ fn serialize_headers<S: Serializer>(
     s.end()
 }
 
+#[derive(Debug, PartialEq, Serialize)]
+#[serde(rename_all = "camelCase")]
+pub struct MetaWebhook {
+    pub name: &'static str,
+    pub operation: MetaOperation,
+}
+
 #[derive(Debug, PartialEq, Serialize)]
 #[serde(rename_all = "camelCase")]
 pub struct MetaOperation {
@@ -486,6 +493,13 @@ pub struct MetaServer {
     pub description: Option<String>,
 }
 
+#[derive(Debug, Default, PartialEq, Serialize)]
+pub struct MetaExternalDocument {
+    pub url: String,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub description: Option<String>,
+}
+
 #[derive(Debug, Serialize)]
 pub struct MetaTag {
     pub name: &'static str,
